@@ -40,6 +40,11 @@ class Forge(object):
         self.stubs = StubManager(self)
         self.attributes.reset_replay_attributes()
 
+    @contextmanager
+    def record_context(self):
+        assert self.is_recording()
+        yield
+
     @contextmanager
     def verified_replay_context(self):
         self.replay()
@@ -105,4 +110,7 @@ class Forge(object):
     def ordered(self):
         return self.queue.get_ordered_group_context()
 
+    def interleaved_order(self):
+        return self.queue.get_interleaved_group_context()
+
     group = ordered
